<?php 

$lang['ln_lang'] = 'Language';
$lang['ln_content'] = 'Content';
$lang['ln_document_type'] = 'Document Type';
$lang['Enter resource id'] = 'Enter resource id';

$lang['btn_save'] = 'Save';
$lang['btn_cancel'] = 'Close current tab';
$lang['btn_close_other'] = 'Close other tabs';

$lang['msg_saved'] = 'Data saved successfully';
$lang['msg_fail'] = 'Error saving data';

$lang['Date not saved. Close current tab?'] = 'The data was not saved. Close Tab?';

$lang['Folder'] = 'Folder';
$lang['Page template'] = 'Page template';
$lang['Page'] = 'Page';
$lang['Resource'] = 'Resource';