div.resmng_nav {
    float: left;
    width: 20%;
}
div.resmng_nav .tab-content{
    overflow: visible;
}
.resmng_content{
    float: left;
    padding-left: 3%;
    width: 77%;
}
.form-actions-top {
    padding: 5px 0;
}
.resmng_tree_menu > .sub-menu{
    height: 600px;
    overflow-y: auto;
}
div.res_search{
    width: 90%;
    margin: 0 auto;
    padding-bottom: 10px;
}
div.res_search input {
    width: 90%
}