<?php 

$lang['Page data'] = 'Дані сторінки';
$lang['Page name in admin panel'] = 'Назва в адмін панелі';
$lang['Page alias'] = 'Псевдонім сторінки';
$lang['Active'] = 'Відображати?';
$lang['SEO'] = 'SEO';
$lang['Title'] = 'Заголовок';
$lang['Keywords'] = 'Ключеві слова';
$lang['Description'] = 'Опис';
$lang['This field specifies the URL to the page. <br />For example, if you write `my_page` then page will be available at `http://mydomain.com/my_page`'] = 'В поточному полі вказується посилання(URL) на сторінку. <br />Наприклад, якщо ввести `my_page` то сторінка буде доступна за адресою `http://mydomain.com/my_page`';
