<?php 

$lang['ln_page_template'] = 'Шаблон страницы';
$lang['ln_alias'] = 'Псевдоним';
$lang['ln_route'] = 'Роутинг';
$lang['ln_cache'] = 'Кэшировать страницу';
$lang['ln_active'] = 'Активная';
$lang['ln_seo_title'] = 'SEO title';
$lang['ln_seo_keywords'] = 'SEO keywords';
$lang['ln_seo_description'] = 'SEO description';
