<?php 

$lang['module_name'] = 'Resource Manager';

$lang['resmng_actions'] = array(
    'resmng_view' => 'View the Resource Manager',
    'private' => 'View private items',
    'edite_private' => 'Changing the visibility',
    'create_element' => 'Create item',
    'rename_element' => 'Rename item',
    'remove_element' => 'Remove item',
    'delete_element' => 'Delete item',
    'clone_element' => 'Clone element',
    'edit_page_content' => 'Edit page content',
    'edit_page_template' => 'Edit page template',
    'edit_resource_content' => 'Edit the contents of the resource',
    'delete_from_trash' => 'Delete from trash',
    'recove_from_trash' => 'Recovery from trash'
);