<?php 

$lang['ln_resource'] = 'Resources';
$lang['ln_deleted'] = 'Trash';

$lang['item_refresh'] = 'Refresh';
$lang['item_rename'] = 'Rename';
$lang['item_create'] = 'Create';
$lang['item_delete'] = 'Delete';
$lang['item_clone'] = 'Clone';

$lang['item_recovery'] = 'Recovery';
$lang['item_clear'] = 'Clear';