<table class="table">
    <thead>
        <tr>
            <th</th>
            <th></th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td><?= $this->lang->line('ln_document_type') ?></td>
            <td>
                <select name="mime_type">
                    <?php foreach ($mime_types as $mime_type): ?>
                        <?php if ($mime_type['active']): ?>
                            <option selected="selected" value="<?= $mime_type['value'] ?>"><?= $mime_type['label'] ?></option>
                        <?php else: ?>
                            <option value="<?= $mime_type['value'] ?>"><?= $mime_type['label'] ?></option>
                        <?php endif; ?>
                    <?php endforeach; ?>
                </select>
            </td>
        </tr>
        <tr>
            <th style="width: 15%"><?= $this->lang->line('ln_lang') ?></th>
            <th><?= $this->lang->line('ln_content') ?></th>
        </tr>
        {item}
        <tr>
            <td>
                <p>{name}</p>
            </td>
            <td>
                <textarea name="content[{id_lan}]" rows="15" style="width: 95%">{content}</textarea>
            </td>
        </tr>
        {/item}
    </tbody>
</table>

