<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Upgrade module to version 1.0.8
 *
 * @author Igor Ratsun
 */
class resmng_upgrade_1_0_7 extends Abstract_upgrade
{

    public function up()
    {
        return '1.0.8';
    }

    public function down()
    {
        return '1.0.7';
    }

}
