<?php

return[
    'resmng_welcome' => [
        'label'        => 'Управление ресурсами CMS',
        'file'         => __DIR__ . '/../docs/welcome.md',
        'position'     => 20,
        'acl_resource' => 'resmng',
        'acl_action'   => 'resmng_view',
        'uri'          => 'resmng/manager',
        'pages'        => [
            'cms_catalog'  => [
                'label'    => 'Каталог',
                'file'     => __DIR__ . '/../docs/catalog.md',
                'position' => 10,
            ],
            'cms_tpl'      => [
                'label'    => 'Шаблон страницы',
                'file'     => __DIR__ . '/../docs/template.md',
                'position' => 20,
            ],
            'cms_page'     => [
                'label'    => 'Страница',
                'file'     => __DIR__ . '/../docs/page.md',
                'position' => 30,
            ],
            'cms_resource' => [
                'label'    => 'Ресурс',
                'file'     => __DIR__ . '/../docs/resource.md',
                'position' => 40,
            ]
        ]
    ],
];
