{form_open}
<div class="navbar-inner">
    <div class="form-actions-top">
        <button type="submit" class="btn"><i class="icon-ok"></i> {btn_save}</button>
        <button type="button" class="btn btnCancel"><i class="icon-remove"></i> {btn_cancel}</button>
        <button type="button" class="btn btnCloseOther"><i class="icon-remove"></i> {btn_close_other}</button>
    </div>
</div>
{content}

{hidden}
{form_close}