<table class="table">
    <thead>
        <tr>
            <th></th>
            <th></th>
        </tr>
    </thead>
    <tbody>
        <?php if (!empty($rpt_options)) { ?>
            <tr>
                <td>{ln_page_template}</td>
                <td>
                    <select name="id_resource_type_page_template">
                        {rpt_options}
                        <option value="{id_resource_type_page_template}" {selected}>{name}</option>
                        {/rpt_options}
                    </select>
                </td>
            </tr>
        <?php } ?>
        <?php if ($this->rt_user->isAllowed('resmng', 'private')) { ?>
            <tr>
                <td><i class="icon-eye-close"></i> {ln_route}</td>
                <td><input type="text" name="route" value="{route}" /></td>
            </tr>
        <?php } ?>
        <tr>
            <td>{ln_alias}</td>
            <td><input type="text" name="alias" value="{alias}" /></td>
        </tr>
        <tr>
            <td>{ln_cache}</td>
            <td><input type="checkbox" name="cache" {cache} /></td>
        </tr>
        <tr>
            <td>{ln_active}</td>
            <td><input type="checkbox" name="active" {checked} /></td>
        </tr>
        <tr>
            <td colspan="2">
                <ul class="nav nav-tabs" id="seo_tab_{seo_id}">
                    {seo_lang_title}
                    <li><a href="#seo_tab_data_{seo_id}_{id_lan}">{lan_name}</a></li>
                    {/seo_lang_title}
                </ul>

                <div class="tab-content">
                    {seo_lang_data}
                    <div class="tab-pane form-horizontal" id="seo_tab_data_{seo_id}_{id_lan}">
                        <div class="control-group">
                            <label class="control-label"><?= $this->lang->line('ln_seo_title') ?></label>
                            <div class="controls">
                                <textarea name="seo_title[{id_lan}]" class="span5" rows="5">{seo_title}</textarea>
                            </div>
                        </div>
                        <div class="control-group">
                            <label class="control-label"><?= $this->lang->line('ln_seo_keywords') ?></label>
                            <div class="controls">
                                <textarea name="seo_keywords[{id_lan}]" class="span5" rows="5">{seo_keywords}</textarea>
                            </div>
                        </div>
                        <div class="control-group">
                            <label class="control-label"><?= $this->lang->line('ln_seo_description') ?></label>
                            <div class="controls">
                                <textarea name="seo_description[{id_lan}]" class="span5" rows="5">{seo_description}</textarea>
                            </div>
                        </div>
                    </div>
                    {/seo_lang_data}
                </div>
            </td>
        </tr>
    </tbody>
</table>

<script type="text/javascript">
    $('#seo_tab_{seo_id} a').click(function(e) {
        e.preventDefault();
        $(this).tab('show');
    });
    $('#seo_tab_{seo_id} a:first').tab('show');
</script>