<?php 

$lang['ln_lang'] = 'Мова';
$lang['ln_content'] = 'Зміст';
$lang['ln_document_type'] = 'Тип документу';
$lang['Enter resource id'] = 'Введіть id ресурса';

$lang['btn_save'] = 'Зберегти';
$lang['btn_cancel'] = 'Закрити поточну вкладку';
$lang['btn_close_other'] = 'Закрити інші вкладки';

$lang['msg_saved'] = 'Дані успішно збережені';
$lang['msg_fail'] = 'Помилка збереження даних';

$lang['Date not saved. Close current tab?'] = 'Дані не були збережені. Закрити вкладку?';

$lang['Folder'] = 'Каталог';
$lang['Page template'] = 'Шаблон сторінки';
$lang['Page'] = 'Сторінка';
$lang['Resource'] = 'Ресурс';